( cd usr/lib ; rm -rf libshp.so )
( cd usr/lib ; ln -sf libshp.so.1.0.1 libshp.so )
( cd usr/lib ; rm -rf libshp.so.1 )
( cd usr/lib ; ln -sf libshp.so.1.0.1 libshp.so.1 )
( cd usr/lib ; rm -rf libshp.la )
( cd usr/lib ; ln -sf ../libshp.la libshp.la )
